==> haskell-websockets-0.12.7.3-193-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-6Q7zYeobcCQkNPdWkMzbh
key:                  websockets-0.12.7.3-6Q7zYeobcCQkNPdWkMzbh
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  0f7a3a530b4c5adc118bcfe4fd7509c5
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-6Q7zYeobcCQkNPdWkMzbh
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    async-2.2.5-KaaU7v9oGWkP1WQtHjJ0p
    attoparsec-0.14.4-99Ep8AgC5YbKR8GAd3oR9D base-4.17.2.1
    base64-bytestring-1.2.1.0-7CU13IWnWdcDMU9nDc25iT binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-EZuETxE1IO9HODmjZlC6xu
    clock-0.8.4-Er7AM7RTUZ54f971dMUbGV containers-0.6.7
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-3.1.4.0-3FUQiZBqCiD6JAPkelGiT0
    random-1.2.1.3-8qBO4jKvrkh2o7oxGJ8dv
    streaming-commons-0.2.3.0-Fkct428BAhUHLN5WGTq3EG text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.12.7.3-194-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-ANP8sEUhv5R4bA6LcjNMZF
key:                  websockets-0.12.7.3-ANP8sEUhv5R4bA6LcjNMZF
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  d85b5b76660ca07959c217956183d70e
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-ANP8sEUhv5R4bA6LcjNMZF
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    async-2.2.5-JCyrUQO4ybIvbhfv5Zh73
    attoparsec-0.14.4-263Fn5MXyjqGBhD6CjKCLb base-4.17.2.1
    base64-bytestring-1.2.1.0-LNkxyXoRMflHvQaufiNrDL binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-EW9gF4gHig7HSWPJPd5ucb
    clock-0.8.4-GNLMDr7l85E5eNVlJYYxKf containers-0.6.7
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-3.1.4.0-4q2nDdk2jYz5m5sp4PhmqQ
    random-1.2.1.3-En8KGuEyE1eKrUFL64LDNm
    streaming-commons-0.2.3.0-2RqLpywV9OhBgFq1mqiDZQ text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
